==> last_gui_package_2016_09_20_14_28_15.zip: evserv/protected/config/mode_development.php <==
<?php

return array(
  'yiiDebug' => true,
  'yiiTraceLevel' => 0,

  'configWeb' => array(
    'modules'=>array(
      'gii'=>array(
        'class'=>'system.gii.GiiModule',
        'password'=>'kria',
        'ipFilters'=>array('127.0.0.1','::1'),
        'generatorPaths'=>array(
          'bootstrap.gii',
        ),
      ),
    ),
    'components' => array(
      'db'=>array(
        'connectionString' => 'mysql:host=127.0.0.1;dbname=eventserverdb',
        'emulatePrepare' => true,
        'username' => 'kria',
        'password' => kria_load_secret('db'),
        'charset' => 'utf8',
        'tablePrefix' => '',
        'enableProfiling'=>true,
        'enableParamLogging'=>true,
      ),
    ),
    'params' => array(
      'photoBaseUrl' => '/photos',
      'photoBasePath' => dirname(__FILE__).'/../../../photos',

    		'log4php' => array(
    				'rootLogger' => array(
    						'appenders' => array(),
    				),
    				'eventserver-gui' => array(
    						'appenders' => array('syslog'),  // see main for log enabling
    				),
    				'appenders' => array(
    						'file' => array(
    								'class' => 'LoggerAppenderFile',
    								'layout' => array(
    										'class' => 'LoggerLayoutSimple'
    								),
    								'params' => array(
    										'file' => 'c:/testlog4php.log',
    										'append' => true
    								)
    						),
    						'socket' => array(
    								'class' => 'LoggerAppenderSocket',
    								'layout' => array(
    										'class' => 'LoggerLayoutPattern',
    										'params' => array(
    												'conversionPattern' => '%date %logger %-5level %msg%n',
    										)
    								),
    								'params' => array(
    										'remoteHost' => '127.0.0.1',
    										'port' => 6101
    								)
    						),
    						'syslog' => array(
    								'class' => 'LoggerAppenderSyslog',
    								'layout' => array(
    										'class' => 'LoggerLayoutSimple',
    								),
    								'params' => array(
    										'ident' => 'eventserver-gui',
    										'facility' => 'USER',
    										'option'	 => 'NDELAY|PID',
    								)
    						),
    				)
    		),    		
    		
    		
    ),
  ),
);

==> last_gui_package_2019_09_27_04_56_43.zip: evserv/protected/config/mode_development.php <==
<?php

return array(
  'yiiDebug' => true,
  'yiiTraceLevel' => 0,

  'configWeb' => array(
    'modules'=>array(
      'gii'=>array(
        'class'=>'system.gii.GiiModule',
        'password'=>'kria',
        'ipFilters'=>array('127.0.0.1','::1'),
        'generatorPaths'=>array(
          'bootstrap.gii',
        ),
      ),
    ),
    'components' => array(
      'db'=>array(
        'connectionString' => 'mysql:host=127.0.0.1;dbname=eventserverdb',
        'emulatePrepare' => true,
        'username' => 'kria',
        'password' => kria_load_secret('db'),
        'charset' => 'utf8',
        'tablePrefix' => '',
        'enableProfiling'=>true,
        'enableParamLogging'=>true,
      ),
    		'registration_db'=>array(
    				'connectionString' => 'mysql:host=31.14.140.159;dbname=eventserver_monitor',
    				'emulatePrepare' => true,
    				'username' => 'testuser',
    				'password' => kria_load_secret('registration_db'),
    				'charset' => 'utf8',
    				'tablePrefix' => '',
    				'enableProfiling'=>false,
    				'enableParamLogging'=>false,
    				'schemaCachingDuration' => 3600,
    				'class'            => 'CDbConnection'
    		),
    ),
    'params' => array(
      'photoBaseUrl' => '/photos',
      'photoBasePath' => dirname(__FILE__).'/../../../photos',

    		'log4php' => array(
    				'rootLogger' => array(
    						'appenders' => array(),
    				),
    				'eventserver-gui' => array(
    						'appenders' => array('syslog'),  // see main for log enabling
    				),
    				'appenders' => array(
    						'file' => array(
    								'class' => 'LoggerAppenderFile',
    								'layout' => array(
    										'class' => 'LoggerLayoutSimple'
    								),
    								'params' => array(
    										'file' => 'c:/testlog4php.log',
    										'append' => true
    								)
    						),
    						'socket' => array(
    								'class' => 'LoggerAppenderSocket',
    								'layout' => array(
    										'class' => 'LoggerLayoutPattern',
    										'params' => array(
    												'conversionPattern' => '%date %logger %-5level %msg%n',
    										)
    								),
    								'params' => array(
    										'remoteHost' => '127.0.0.1',
    										'port' => 6101
    								)
    						),
    						'syslog' => array(
    								'class' => 'LoggerAppenderSyslog',
    								'layout' => array(
    										'class' => 'LoggerLayoutSimple',
    								),
    								'params' => array(
    										'ident' => 'eventserver-gui',
    										'facility' => 'USER',
    										'option'	 => 'NDELAY|PID',
    								)
    						),
    				)
    		),    		
    		
    		
    ),
  ),
);
